@@ -1,4 +1,3 @@
-import os
 import pytest
 import botocore.client
 import aviv_aws_costexplorer.costreporter as cr
@@ -19,7 +18,7 @@ def test_metadata():
     rec = {"TimePeriod": {"Start": "yyyy", "End": "yyyy"}}
     obj = cr.CostReporter()
 
-    os.environ['AWS_CE_REQUESTID'] = '1'
+    cr.AWS_CE_REQUESTID = '1'
     obj._stamp_record(rec, {"RequestId": "xxxxx-yyyyy"})
     assert 'Start' in rec
     assert 'End' in rec
@@ -30,3 +29,20 @@ def test_connection():
     obj = cr.CostReporter()
     assert isinstance(obj.sts, botocore.client.BaseClient)
     assert str(obj.sts.__class__) == "<class 'botocore.client.STS'>"
+
+def test_stamp_record_period():
+    obj = cr.CostReporter()
+
+    obj.granularity='monthly'
+    record = {"TimePeriod": {"Start": "2021-04-21"}}
+    obj._stamp_record(record, {})
+    assert record['Period'] == "202104"
+
+    record = {"TimePeriod": {"Start": "2021-04-20T13:45:30"}}
+    obj._stamp_record(record, {})
+    assert record['Period'] == "202104"
+
+    obj.granularity = 'daily'
+    record = {"TimePeriod": {"Start": "2021-04-20T13:45:30"}}
+    obj._stamp_record(record, {})
+    assert record['Period'] == "20210420"
